package productlogic

import (
	"context"
	"tianyuan-api/pkg/sqlutil"

	"tianyuan-api/apps/sentinel/internal/svc"
	"tianyuan-api/apps/sentinel/sentinel"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetProductPageListLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetProductPageListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetProductPageListLogic {
	return &GetProductPageListLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *GetProductPageListLogic) GetProductPageList(in *sentinel.PageListRequest) (*sentinel.ProductResponse, error) {
	products, total, err := l.svcCtx.ProductsModel.FindProductsList(l.ctx, in.Page, in.PageSize)
	if err != nil {
		return nil, err
	}
	var list []*sentinel.Product
	for _, p := range products {
		list = append(list, &sentinel.Product{
			Id:                 p.Id,
			ProductName:        p.ProductName,
			ProductCode:        p.ProductCode,
			ProductDescription: sqlutil.NullStringToString(p.ProductDescription),
			ProductGroup:       p.ProductGroup,
			ProductPrice:       p.ProductPrice,
		})
	}
	return &sentinel.ProductResponse{
		Total:    total,
		Products: list,
	}, nil
}
